@@ -20,7 +20,7 @@
 (*                                                                        *)
 (**************************************************************************)
 
-(* $Id$ *)
+(* $Id: gMisc.ml 1419 2008-09-22 13:37:06Z zoggy $ *)
 
 open Gaux
 open Gobject
@@ -65,13 +65,11 @@ class status_icon_signals (obj : Gtk.status_icon Gobject.obj) = object
     inherit gtk_status_icon_sigs
     method private connect sgn ~callback =
       GtkSignal.connect ~sgn ~callback ~after: true obj
-    method private notify prop ~callback =
-      GtkSignal.connect_property obj ~prop ~callback
 end
 
 class status_icon obj = object
-  val obj : Gtk.status_icon Gobject.obj = obj
   inherit gtk_status_icon_props
+  method obj : Gtk.status_icon Gobject.obj = obj
   method connect = new status_icon_signals obj
   method set_from_pixbuf = StatusIcon.set_from_pixbuf obj
   method set_from_file = StatusIcon.set_from_file obj
@@ -148,34 +146,16 @@ let calendar ?options ?packing ?show () =
   pack_return (new calendar w) ~packing ~show
 
 class drawing_area obj = object
-  inherit widget_full (obj : [> Gtk.drawing_area] obj)
+  inherit widget_full (obj : Gtk.drawing_area obj)
   method event = new GObj.event_ops obj
   method set_size = DrawingArea.size obj
 end
 
-let may_set_size ?(width=0) ?(height=0) w =
-  if width <> 0 || height <> 0 then DrawingArea.size w ~width ~height
-
-let drawing_area ?width ?height ?packing ?show () =
+let drawing_area ?(width=0) ?(height=0) ?packing ?show () =
   let w = DrawingArea.create [] in
-  may_set_size w ?width ?height;
+  if width <> 0 || height <> 0 then DrawingArea.size w ~width ~height;
   pack_return (new drawing_area w) ~packing ~show
 
-class curve obj = object
-  inherit drawing_area (obj : Gtk.curve obj)
-  inherit curve_props
-  method reset () = Curve.reset obj
-  method set_gamma = Curve.set_gamma obj
-  method set_vector = Curve.set_vector obj
-  method get_vector = Curve.get_vector obj
-end
-
-let curve ?width ?height =
-  Curve.make_params [] ~cont:(fun pl ?packing ?show () ->
-    let w = Curve.create pl in
-    may_set_size w ?width ?height;
-    pack_return (new curve w) ~packing ~show)
-
 class misc obj = object
   inherit ['a] widget_impl obj
   inherit misc_props
@@ -217,8 +197,8 @@ let pixmap pm =
 class label_skel obj = object(self)
   inherit misc obj
   inherit label_props
-  method text = GtkMiscProps.Label.get_text obj
-  method set_text = GtkMiscProps.Label.set_text obj
+  method text = GtkMiscProps.Label.get_text self#obj
+  method set_text = GtkMiscProps.Label.set_text self#obj
   method selection_bounds = GtkMiscProps.Label.get_selection_bounds obj
   method select_region = GtkMiscProps.Label.select_region obj
 end
