@@ -20,7 +20,7 @@
 (*                                                                        *)
 (**************************************************************************)
 
-(* $Id$ *)
+(* $Id: gtkTree.ml 1421 2008-09-22 19:00:48Z ben_99_9 $ *)
 
 open Gaux
 open Gtk
@@ -58,10 +58,7 @@ module TreePath = struct
   let () =
     Internal.tree_path_string :=
       {kind=`STRING; inj=(fun x -> string.inj (to_string x));
-       proj=(fun x -> from_string (string.proj x))};
-    Internal.tree_path_copy :=
-      {kind=`POINTER; inj=unsafe_pointer.inj;
-       proj=(fun x -> copy (unsafe_pointer.proj x))}
+       proj=(fun x -> from_string (string.proj x))}
 end
 
 module RowReference = struct
@@ -74,7 +71,7 @@ module RowReference = struct
 end
 
 module TreeModel = struct
-  let cast w : tree_model = Object.try_cast w "GtkTreeModel"
+  let cast w : tree_model obj = Object.try_cast w "GtkTreeModel"
   external get_flags : [>`treemodel] obj -> GtkEnums.tree_model_flags list
     = "ml_gtk_tree_model_get_flags"
   external get_n_columns : [>`treemodel] obj -> int
@@ -278,11 +275,7 @@ module TreeViewColumn = struct
     = "ml_gtk_tree_view_column_get_sort_column_id"
   external set_cell_data_func : 
     [>`treeviewcolumn] obj -> [>`cellrenderer] obj -> 
-    ([`treemodel] obj -> tree_iter -> unit) option -> unit
-  = "ml_gtk_tree_view_column_set_cell_data_func"
-  external get_button :
-    [>`treeviewcolumn] obj -> Gtk.button obj
-    = "ml_gtk_tree_view_column_get_button"
+    ([`treemodel] obj -> tree_iter -> unit) option -> unit = "ml_gtk_tree_view_column_set_cell_data_func"
 end
 
 module TreeView = struct
@@ -350,57 +343,6 @@ module TreeView = struct
     [>`treeview] obj ->
     (Gtk.tree_model -> Gtk.tree_iter -> bool) option -> unit
     = "ml_gtk_tree_view_set_row_separator_func"
-  
-  (** @since GTK 2.12 *)
-  module Tooltip = struct
-    external set_cell :
-      [>`treeview] obj -> Gtk.tooltip ->
-      ?path:Gtk.tree_path ->
-      ?col:tree_view_column obj ->
-      ?cell:[>`cellrenderer] obj ->
-      unit -> unit
-      = "ml_gtk_tree_view_set_tooltip_cell_bc" "ml_gtk_tree_view_set_tooltip_cell"
-    external set_row :
-      [>`treeview] obj -> Gtk.tooltip -> Gtk.tree_path -> unit
-      = "ml_gtk_tree_view_set_tooltip_row"
-    external get_context :
-      [>`treeview] obj ->
-      x: int -> y: int -> kbd: bool ->
-      (int * int * (Gtk.tree_model * Gtk.tree_path * Gtk.tree_iter) option)
-      = "ml_gtk_tree_view_get_tooltip_context"
-    external get_column :
-      [>`treeview] obj -> int
-      = "ml_gtk_tree_view_get_tooltip_column"
-    external set_column :
-      [>`treeview] obj -> int -> unit
-      = "ml_gtk_tree_view_set_tooltip_column"
-  end
-  
-  module Dnd = struct
-    external get_dest_row_at_pos :
-      [>`treeview] obj ->
-      x: int -> y: int ->
-      ( Gtk.tree_path
-      * GtkEnums.tree_view_drop_position ) option
-      = "ml_gtk_tree_view_get_dest_row_at_pos"
-    external enable_model_drag_dest :
-      [>`treeview] obj ->
-      targets: target_entry array ->
-      actions: Gdk.Tags.drag_action list -> unit
-      = "ml_gtk_tree_view_enable_model_drag_dest"
-    external unset_rows_drag_dest :
-      [>`treeview] obj -> unit
-      = "ml_gtk_tree_view_unset_rows_drag_dest"
-    external enable_model_drag_source :
-      [>`treeview] obj ->
-      ?modi: Gdk.Tags.modifier list ->
-      targets: target_entry array ->
-      actions: Gdk.Tags.drag_action list -> unit
-      = "ml_gtk_tree_view_enable_model_drag_source"
-    external unset_rows_drag_source :
-      [>`treeview] obj -> unit
-      = "ml_gtk_tree_view_unset_rows_drag_source"
-  end
 end
 
 module CellRenderer = CellRenderer
