@@ -20,7 +20,7 @@
 /*                                                                        */
 /**************************************************************************/
 
-/* $Id$ */
+/* $Id: ml_gdk.c 1428 2008-10-30 17:02:27Z ben_99_9 $ */
 
 #include <string.h>
 #include <gdk/gdk.h>
@@ -55,11 +55,9 @@
 #define GDK_WINDOW_TYPE_HINT_DOCK GDK_WINDOW_TYPE_HINT_NORMAL
 #endif
 
-CAMLexport lookup_info *ml_table_extension_events;
-
 CAMLprim void ml_raise_gdk (const char *errmsg)
 {
-  static const value * exn = NULL;
+  static value * exn = NULL;
   if (exn == NULL)
       exn = caml_named_value ("gdkerror");
   raise_with_string (*exn, (char*)errmsg);
@@ -88,19 +86,6 @@ CAMLprim value ml_test_##conv (value mask, value test) \
 Make_test(GdkModifier_val)
 Make_test(GdkWindowState_val)
 
-/* Platform */
-
-value ml_gdk_get_platform()
-{
-#ifdef GDK_WINDOWING_WIN32
-  return MLTAG_WIN32;
-#elif defined(GDK_WINDOWING_QUARTZ)
-  return MLTAG_QUARTZ;
-#else
-  return MLTAG_X11;
-#endif
-}
-
 /* Colormap */
 
 ML_0 (gdk_colormap_get_system, Val_GdkColormap)
@@ -268,19 +253,16 @@ CAMLprim value ml_gdk_drawable_get_size (value drawable)
 ML_3 (gdk_window_set_back_pixmap, GdkWindow_val, GdkPixmap_val, Int_val, Unit)
 ML_2 (gdk_window_set_cursor, GdkWindow_val, GdkCursor_val, Unit)
 ML_1 (gdk_window_clear, GdkWindow_val, Unit)
-ML_5 (gdk_window_clear_area, GdkWindow_val, Int_val, Int_val, Int_val, Int_val,
-      Unit)
 ML_0 (GDK_ROOT_PARENT, Val_GdkWindow)
 ML_1 (gdk_window_get_parent, GdkWindow_val, Val_GdkWindow)
-ML_2 (gdk_window_set_transient_for, GdkWindow_val, GdkWindow_val, Unit)
-ML_1 (gdk_window_foreign_new, GdkNativeWindow_val, Val_GdkWindow)
 
 #if defined(_WIN32) || defined(__CYGWIN__) || defined(HAS_GTKQUARTZ)
 CAMLprim value ml_GDK_WINDOW_XWINDOW(value v)
 {
- ml_raise_gdk ("ml_GDK_WINDOW_XWINDOW: only for X11");
+ ml_raise_gdk ("Not available for Win32");
  return Val_unit;
-}
+} 
+
 #else
 ML_1 (GDK_WINDOW_XWINDOW, GdkDrawable_val, Val_XID)
 #endif
@@ -480,7 +462,7 @@ CAMLprim value copy_xdata (gint format, void *xdata, gulong nitems)
     switch (format) {
     case 8:
         data = alloc_string (nitems);
-        memcpy (Bytes_val(data), xdata, sizeof(char) * nitems);
+        memcpy (String_val(data), xdata, sizeof(char) * nitems);
         tag = MLTAG_BYTES;
         break;
     case 16:
@@ -881,8 +863,7 @@ Make_Extractor (GdkEventSelection, GdkEvent_arg(Selection), target,
                 Val_GdkAtom)
 Make_Extractor (GdkEventSelection, GdkEvent_arg(Selection), property,
                 Val_GdkAtom)
-Make_Extractor (GdkEventSelection, GdkEvent_arg(Selection), requestor,
-                Val_GdkNativeWindow)
+Make_Extractor (GdkEventSelection, GdkEvent_arg(Selection), requestor, Val_XID)
 
 Make_Extractor (GdkEventProximity, GdkEvent_arg(Proximity),
                 device, Val_GdkDevice)
