@@ -20,7 +20,7 @@
 /*                                                                        */
 /**************************************************************************/
 
-/* $Id$ */
+/* $Id: ml_gtk.c 1402 2008-03-25 08:55:03Z garrigue $ */
 
 #include <string.h>
 #include <gtk/gtk.h>
@@ -43,7 +43,7 @@
 
 void ml_raise_gtk (const char *errmsg)
 {
-  static const value * exn = NULL;
+  static value * exn = NULL;
   if (exn == NULL)
       exn = caml_named_value ("gtkerror");
   raise_with_string (*exn, (char*)errmsg);
@@ -122,39 +122,10 @@ CAMLprim value ml_gtk_accelerator_parse(value acc)
   Field(tup, 1) = vmods;
   CAMLreturn(tup);
 }
-ML_2(gtk_accelerator_name, Int_val, OptFlags_GdkModifier_val,
-     copy_string_g_free)
-ML_2(gtk_accelerator_get_label, Int_val, OptFlags_GdkModifier_val,
-     copy_string_g_free)
 
 ML_1(gtk_accel_map_load,String_val,Unit)
 ML_1(gtk_accel_map_save,String_val,Unit)
 ML_3(gtk_accel_map_add_entry,String_val,Int_val, OptFlags_GdkModifier_val, Unit)
-ML_4(gtk_accel_map_change_entry,String_val,Int_val, OptFlags_GdkModifier_val,
-     Bool_val, Val_bool)
-
-static void accel_map_func (gpointer data,
-                            const gchar *accel_path,
-                            guint accel_key,
-                            GdkModifierType accel_mods,
-                            gboolean changed)
-{
-    value args[4];
-    args[0] = Val_string (accel_path);
-    args[1] = Val_int(accel_key);
-    Begin_roots1(args[0]);
-    args[2] = Val_GdkModifier_flags(accel_mods);
-    End_roots();
-    args[3] = Val_int(changed);
-    caml_callbackN_exn (*(value*)data, 4, args);
-}
-
-CAMLprim value ml_gtk_accel_map_foreach(value func)
-{
-    CAMLparam1(func);
-    gtk_accel_map_foreach (&func, accel_map_func);
-    CAMLreturn(Val_unit);
-}
 
 /* gtkstyle.h */
 
@@ -231,10 +202,9 @@ ML_1 (gtk_object_sink, GtkObject_val, Unit)
 ML_6 (gtk_adjustment_new, Float_val, Float_val, Float_val, Float_val,
       Float_val, Float_val, Val_GtkObject_sink)
 ML_bc6 (ml_gtk_adjustment_new)
+ML_2 (gtk_adjustment_set_value, GtkAdjustment_val, Float_val, Unit)
 ML_3 (gtk_adjustment_clamp_page, GtkAdjustment_val,
       Float_val, Float_val, Unit)
-/*
-ML_2 (gtk_adjustment_set_value, GtkAdjustment_val, Float_val, Unit)
 Make_Extractor (gtk_adjustment_get, GtkAdjustment_val, lower, copy_double)
 Make_Extractor (gtk_adjustment_get, GtkAdjustment_val, upper, copy_double)
 Make_Extractor (gtk_adjustment_get, GtkAdjustment_val, value, copy_double)
@@ -248,7 +218,7 @@ CAMLprim value ml_gtk_adjustment_set(value lower, value upper,
                             value page_size, value adjustment)
 {
     GtkAdjustment *adj = GtkAdjustment_val(adjustment);
-#define Update_field(name) (adj->name = Option_val(name,Double_val,adj->name)
+#define Update_field(name) adj->name = Option_val(name,Double_val,adj->name)
     Update_field(lower);
     Update_field(upper);
     Update_field(step_increment);
@@ -258,7 +228,6 @@ CAMLprim value ml_gtk_adjustment_set(value lower, value upper,
     return Val_unit;
 }
 ML_bc6(ml_gtk_adjustment_set)
-*/
 
 /* gtktooltips.h */
 
@@ -397,12 +366,12 @@ CAMLprim value ml_gtk_widget_style_get_property (value w, value n)
     CAMLparam2 (w, n);
     CAMLlocal1 (ret);
     GtkWidget *widget = GtkWidget_val (w);
-    gchar *name = (gchar*)Bytes_val (n);
+    gchar *name = String_val (n);
     GParamSpec * pspec;
     pspec = gtk_widget_class_find_style_property
                (GTK_WIDGET_GET_CLASS (widget), name);
     if (pspec) {
-        ret = ml_g_value_new ();
+        value ret = ml_g_value_new ();
         GValue *gv = GValueptr_val (ret);
         g_value_init (gv, G_PARAM_SPEC_VALUE_TYPE (pspec));
         gtk_widget_style_get_property (widget, name, gv);
@@ -412,28 +381,6 @@ CAMLprim value ml_gtk_widget_style_get_property (value w, value n)
     CAMLreturn (ret);
 }
 
-#ifdef HASGTK212
-ML_1 (gtk_widget_get_tooltip_markup, GtkWidget_val, Val_string)
-ML_2 (gtk_widget_set_tooltip_markup, GtkWidget_val, String_val, Unit)
-ML_1 (gtk_widget_get_tooltip_text, GtkWidget_val, Val_string)
-ML_2 (gtk_widget_set_tooltip_text, GtkWidget_val, String_val, Unit)
-ML_1 (gtk_widget_get_tooltip_window, GtkWidget_val, Val_GtkAny)
-ML_2 (gtk_widget_set_tooltip_window, GtkWidget_val, GtkWindow_val, Unit)
-ML_1 (gtk_widget_get_has_tooltip, GtkWidget_val, Val_bool)
-ML_2 (gtk_widget_set_has_tooltip, GtkWidget_val, Bool_val, Unit)
-ML_1 (gtk_widget_trigger_tooltip_query, GtkWidget_val, Unit)
-#else
-Unsupported_212(gtk_widget_get_tooltip_markup)
-Unsupported_212(gtk_widget_set_tooltip_markup)
-Unsupported_212(gtk_widget_get_tooltip_text)
-Unsupported_212(gtk_widget_set_tooltip_text)
-Unsupported_212(gtk_widget_get_tooltip_window)
-Unsupported_212(gtk_widget_set_tooltip_window)
-Unsupported_212(gtk_widget_get_has_tooltip)
-Unsupported_212(gtk_widget_set_has_tooltip)
-Unsupported_212(gtk_widget_trigger_tooltip_query)
-#endif
-
 /* gtkdnd.h */
 
 CAMLprim value ml_gtk_drag_dest_set (value w, value f, value t, value a)
@@ -448,7 +395,7 @@ CAMLprim value ml_gtk_drag_dest_set (value w, value f, value t, value a)
 	  alloc (Wosize_asize(n_targets * sizeof(GtkTargetEntry)),
 		 Abstract_tag);
   for (i=0; i<n_targets; i++) {
-    targets[i].target = (gchar*)Bytes_val(Field(Field(t, i), 0));
+    targets[i].target = String_val(Field(Field(t, i), 0));
     targets[i].flags = Flags_Target_flags_val(Field(Field(t, i), 1));
     targets[i].info = Int_val(Field(Field(t, i), 2));
   }
@@ -485,7 +432,7 @@ CAMLprim value ml_gtk_drag_source_set (value w, value m, value t, value a)
 	  alloc (Wosize_asize(n_targets * sizeof(GtkTargetEntry)),
 		 Abstract_tag);
   for (i=0; i<n_targets; i++) {
-    targets[i].target = (gchar*)Bytes_val(Field(Field(t, i), 0));
+    targets[i].target = String_val(Field(Field(t, i), 0));
     targets[i].flags = Flags_Target_flags_val(Field(Field(t, i), 1));
     targets[i].info = Int_val(Field(Field(t, i), 2));
   }
@@ -639,10 +586,6 @@ ML_1 (gtk_container_get_resize_mode, GtkContainer_val, Val_resize_mode)
 ML_2 (gtk_container_add, GtkContainer_val, GtkWidget_val, Unit)
 ML_2 (gtk_container_remove, GtkContainer_val, GtkWidget_val, Unit)
 ML_1 (gtk_container_check_resize, GtkContainer_val, Unit)
-ML_4 (gtk_container_child_get_property, GtkContainer_val, GtkWidget_val,
-      String_val, GValue_val, Unit)
-ML_4 (gtk_container_child_set_property, GtkContainer_val, GtkWidget_val,
-      String_val, GValue_val, Unit)
 static void ml_gtk_simple_callback (GtkWidget *w, gpointer data)
 {
     value val, *clos = (value*)data;
@@ -737,9 +680,8 @@ CAMLprim value ml_gtk_file_selection_get_selections (value sel)
   gchar** selections =
     gtk_file_selection_get_selections(GtkFileSelection_val(sel));
   gchar** orig = selections;
-  value ret = Val_unit;
-  CAMLparam1(ret);
-  CAMLlocal2(prev,next);
+  CAMLparam0();
+  CAMLlocal3(ret,prev,next);
   for (prev = (value)((&ret)-1); *selections != NULL; selections++) {
     next = alloc(2,0);
     Store_field(prev, 1, next);
@@ -765,6 +707,7 @@ Make_Extractor (gtk_file_selection_get, GtkFileSelection_val, dir_list,
 
 /* gtkwindow.h */
 
+#define GtkWindow_val(val) check_cast(GTK_WINDOW,val)
 ML_1 (gtk_window_new, Window_type_val, Val_GtkWidget_window)
 /* ML_2 (gtk_window_set_title, GtkWindow_val, String_val, Unit) */
 ML_3 (gtk_window_set_wmclass, GtkWindow_val, String_val, String_val, Unit)
@@ -902,6 +845,52 @@ ml_gtk_about_dialog_set_email_hook (value hook)
   return Val_unit;
 }
 
+static gchar **
+strv_of_string_list (value list)
+{
+  gchar **str_v;
+  gsize i, len;
+  value l;
+  for (len = 0, l = list; l != Val_emptylist; len++, l = Field (l, 1))
+    ;
+  l = list;
+  str_v = g_new (gchar *, len+1);
+  for (i = 0; i < len; i++)
+    {
+      str_v[i] = g_strdup (String_val (Field (l, 0)));
+      l = Field (l, 1);
+    }
+  str_v[len] = NULL;
+  return str_v;
+}
+static value
+string_list_of_strv (const gchar * const *v)
+{
+  CAMLparam0();
+  CAMLlocal4(head, l, cell, s);
+  gsize i;
+  if (v == NULL)
+    CAMLreturn (Val_emptylist);
+  i = 0;
+  head = l = Val_emptylist;
+  while (v[i] != NULL)
+    {
+      s = copy_string (v[i]);
+      cell = alloc_small (2, Tag_cons);
+      Field (cell, 0) = s;
+      Field (cell, 1) = Val_emptylist;
+      if (l == Val_emptylist)
+	  head = l = cell;
+      else
+	{
+	  Field (l, 1) = cell;
+	  l = cell;
+	}
+      i++;
+    }
+  CAMLreturn (head);
+}
+
 #define GtkAboutDialog_val(v) (check_cast (GTK_ABOUT_DIALOG, v))
 
 CAMLprim value
@@ -968,7 +957,7 @@ Make_Extractor (gtk_font_selection_dialog, GtkFontSelectionDialog_val,
 #ifdef _WIN32
 Unsupported(gtk_plug_new)
 #else
-ML_1 (gtk_plug_new, GdkNativeWindow_val, Val_GtkWidget_window)
+ML_1 (gtk_plug_new, XID_val, Val_GtkWidget_window)
 #endif
 
 /* gtksocket.h */
@@ -976,17 +965,11 @@ ML_1 (gtk_plug_new, GdkNativeWindow_val, Val_GtkWidget_window)
 Unsupported(gtk_socket_steal)
 #else
 #define GtkSocket_val(val) check_cast(GTK_SOCKET,val)
-ML_2 (gtk_socket_steal, GtkSocket_val, GdkNativeWindow_val, Unit)
+ML_2 (gtk_socket_steal, GtkSocket_val, XID_val, Unit)
 #endif
 
 /* gtkmain.h */
 
-#ifdef HAS_MODIFY_ARGV
-CAMLextern value caml_sys_modify_argv(value argv);
-#else
-CAMLextern value caml_obj_truncate (value v, value newsize);
-#endif
-
 CAMLprim value ml_gtk_init (value argv)
 {
     CAMLparam1 (argv);
@@ -999,15 +982,9 @@ CAMLprim value ml_gtk_init (value argv)
       ml_raise_gtk ("ml_gtk_init: initialization failed");
     }
 
-#ifdef HAS_MODIFY_ARGV
     argv = (argc ? alloc (argc, 0) : Atom(0));
-    for (i = 0; i < argc; i++) caml_modify(&Field(argv,i), Field(copy,i));
-    caml_sys_modify_argv(argv);
-#else
-    for (i = 0; i < argc; i++) caml_modify(&Field(argv,i), Field(copy,i));
-    caml_obj_truncate(argv, Val_int(argc));
-#endif
-    CAMLreturn (Val_unit);
+    for (i = 0; i < argc; i++) modify(&Field(argv,i), Field(copy,i));
+    CAMLreturn (argv);
 }
 ML_0 (gtk_set_locale, Val_string)
 ML_0 (gtk_disable_setlocale, Unit)
@@ -1036,25 +1013,3 @@ ML_2 (gtk_propagate_event, GtkWidget_val, GdkEvent_val, Unit)
 ML_1 (gtk_rc_add_default_file, String_val, Unit)
 ML_1 (gtk_rc_parse, String_val, Unit)
 ML_1 (gtk_rc_parse_string, String_val, Unit)
-
-/* gtktooltip.h */
-
-#ifdef HASGTK212
-ML_2 (gtk_tooltip_set_markup, GtkTooltip_val, String_val, Unit)
-ML_2 (gtk_tooltip_set_text, GtkTooltip_val, String_val, Unit)
-  /* Note: gtk_tooltip_set_text duplicates the string */
-ML_2 (gtk_tooltip_set_icon, GtkTooltip_val, GdkPixbuf_val, Unit)
-ML_3 (gtk_tooltip_set_icon_from_stock, GtkTooltip_val,
-      String_val, Icon_size_val, Unit)
-ML_2 (gtk_tooltip_set_custom, GtkTooltip_val, GtkWidget_val, Unit)
-ML_1 (gtk_tooltip_trigger_tooltip_query, GdkDisplay_val, Unit)
-ML_2 (gtk_tooltip_set_tip_area, GtkTooltip_val, GdkRectangle_val, Unit)
-#else
-Unsupported_212(gtk_tooltip_set_markup)
-Unsupported_212(gtk_tooltip_set_text)
-Unsupported_212(gtk_tooltip_set_icon)
-Unsupported_212(gtk_tooltip_set_icon_from_stock)
-Unsupported_212(gtk_tooltip_set_custom)
-Unsupported_212(gtk_tooltip_trigger_tooltip_query)
-Unsupported_212(gtk_tooltip_set_tip_area)
-#endif /* HASGTK212 */
