@@ -20,7 +20,7 @@
 /*                                                                        */
 /**************************************************************************/
 
-/* $Id$ */
+/* $Id: ml_pango.c 1347 2007-06-20 07:40:34Z guesdon $ */
 
 #include <stdio.h>
 #include <pango/pango.h>
@@ -110,13 +110,6 @@ ML_1 (pango_font_metrics_get_approximate_digit_width,
 ML_2 (pango_font_get_metrics, PangoFont_val, PangoLanguage_val,
       Val_PangoFontMetrics_new)
 
-/* PangoFontMap */
-
-#define Val_PangoFontMap_new(val) Val_GObject_new(G_OBJECT(val))
-ML_3 (pango_font_map_load_font, PangoFontMap_val, PangoContext_val,
-      PangoFontDescription_val,
-      Val_PangoFont_new)
-
 /* Enums */
 
 CAMLprim value ml_PANGO_SCALE ()
@@ -193,12 +186,6 @@ ML_1 (pango_layout_get_justify, PangoLayout_val, Val_bool)
 ML_2 (pango_layout_set_single_paragraph_mode, PangoLayout_val, Bool_val, Unit)
 ML_1 (pango_layout_get_single_paragraph_mode, PangoLayout_val, Val_bool)
 ML_1 (pango_layout_context_changed, PangoLayout_val, Unit)
-ML_1 (pango_layout_get_baseline, PangoLayout_val, Val_int)
-ML_1 (pango_layout_get_line_count, PangoLayout_val, Val_int)
-ML_1 (pango_layout_is_wrapped, PangoLayout_val, Val_bool)
-ML_1 (pango_layout_is_ellipsized, PangoLayout_val, Val_bool)
-ML_1 (pango_layout_get_alignment, PangoLayout_val, Val_pango_alignment)
-ML_2 (pango_layout_set_alignment, PangoLayout_val, Pango_alignment_val, Unit)
 CAMLprim value ml_pango_layout_get_size(value layout)
 {
   int width, height;
